.. _js-api-ref:

JavaScript API
==============

MusicBox
--------

.. js:autoclass:: MusicBox
   :members: fromJson, fromJsonFile, solve

parseBoxModelOptions
--------------------

.. js:autofunction:: parseBoxModelOptions

parseConditions
---------------

.. js:autofunction:: parseConditions

ConditionsManager
-----------------

.. js:autoclass:: ConditionsManager
   :members: concentrationEvents, getConditionsAtTime

Constants
---------

.. js:autoattribute:: BOLTZMANN_CONSTANT

.. js:autoattribute:: GAS_CONSTANT
